@@ -1,3 +1,5 @@
+import json
+
 from demo_app_handlers import create_handler  # type: ignore
 
 
@@ -49,6 +51,15 @@ def test_post_invalid_empty_json(requests_client, base_url):
     }
 
 
+def test_post_invalid_json(requests_client, base_url):
+    """
+    test that the message is returned to the body
+    """
+    response = create_handler({"path": f"{base_url}/hello", "body": "{"}, None)
+    assert response["statusCode"] == 400
+    assert json.loads(response["body"]) == {"detail": "JSONDecodeError"}
+
+
 def test_inv(mock_lambda_context):
     event = {
         "resource": "/hello",
